@@ -234,12 +234,12 @@ class Tracer(object):
         return ctx
 
     def current_trace_context(self, *args, **kwargs):
-        # type (...) -> Optional[Context]
+        # type: (...) -> Optional[Context]
         """Return the context for the current trace.
 
         If there is no active trace then None is returned.
         """
-        active = self.context_provider.active(*args, **kwargs)
+        active = self.context_provider.active()
         if isinstance(active, Context):
             return active
         elif isinstance(active, Span):
@@ -247,7 +247,6 @@ class Tracer(object):
         return None
 
     # TODO: deprecate this method and make sure users create a new tracer if they need different parameters
-    @debtcollector.removals.removed_kwarg("collect_metrics", removal_version="0.51")
     def configure(
         self,
         enabled=None,  # type: Optional[bool]
@@ -260,7 +259,6 @@ class Tracer(object):
         wrap_executor=None,  # type: Optional[Callable]
         priority_sampling=None,  # type: Optional[bool]
         settings=None,  # type: Optional[Dict[str, Any]]
-        collect_metrics=None,  # type: Optional[bool]
         dogstatsd_url=None,  # type: Optional[str]
         writer=None,  # type: Optional[TraceWriter]
         partial_flush_enabled=None,  # type: Optional[bool]
@@ -286,7 +284,6 @@ class Tracer(object):
             from the default value
         :param priority_sampling: enable priority sampling, this is required for
             complete distributed tracing support. Enabled by default.
-        :param collect_metrics: Whether to enable runtime metrics collection.
         :param str dogstatsd_url: URL for UDP or Unix socket connection to DogStatsD
         """
         if enabled is not None:
@@ -367,7 +364,7 @@ class Tracer(object):
             # No need to do anything for the LogWriter.
             pass
         if isinstance(self.writer, AgentWriter):
-            self.writer.dogstatsd = get_dogstatsd_client(self._dogstatsd_url)
+            self.writer.dogstatsd = get_dogstatsd_client(self._dogstatsd_url)  # type: ignore[has-type]
         self._initialize_span_processors()
 
         if context_provider is not None:
@@ -376,18 +373,6 @@ class Tracer(object):
         if wrap_executor is not None:
             self._wrap_executor = wrap_executor
 
-        runtime_metrics_was_running = False
-        # FIXME: Import RuntimeWorker here to avoid circular imports. This will
-        # be gone together with the collect_metrics attribute soon.
-        from .internal.runtime.runtime_metrics import RuntimeWorker
-
-        if RuntimeWorker._instance is not None:
-            runtime_metrics_was_running = True
-            RuntimeWorker.disable()
-
-        if (collect_metrics is None and runtime_metrics_was_running) or collect_metrics:
-            RuntimeWorker.enable(tracer=self, dogstatsd_url=self._dogstatsd_url)
-
         if debug_mode or asbool(environ.get("DD_TRACE_STARTUP_LOGS", False)):
             try:
                 info = debug.collect(self)
